@@ -1,23 +1,18 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2021 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import json
 import os
 import sys
 from contextlib import contextmanager
-from typing import Dict, Set, Tuple
+from typing import Callable, Dict, Set, Tuple, TypeVar
 
 from hypothesis.internal.reflection import proxies
 
@@ -34,6 +29,7 @@ When not running with a magic environment variable set, this module disables
 itself and has essentially no overhead.
 """
 
+Func = TypeVar("Func", bound=Callable)
 pretty_file_name_cache: Dict[str, str] = {}
 
 
@@ -52,6 +48,7 @@ def pretty_file_name(f):
 
 
 IN_COVERAGE_TESTS = os.getenv("HYPOTHESIS_INTERNAL_COVERAGE") == "true"
+description_stack = []
 
 
 if IN_COVERAGE_TESTS:
@@ -65,22 +62,17 @@ if IN_COVERAGE_TESTS:
         if key in written:
             return
         written.add(key)
-        with open("branch-check", "a") as log:
+        with open(f"branch-check-{os.getpid()}", mode="a", encoding="utf-8") as log:
             log.write(json.dumps({"name": name, "value": value}) + "\n")
 
-    description_stack = []
-
     @contextmanager
     def check_block(name, depth):
         # We add an extra two callers to the stack: One for the contextmanager
         # function, one for our actual caller, so we want to go two extra
         # stack frames up.
         caller = sys._getframe(depth + 2)
-        local_description = "%s at %s:%d" % (
-            name,
-            pretty_file_name(caller.f_code.co_filename),
-            caller.f_lineno,
-        )
+        fname = pretty_file_name(caller.f_code.co_filename)
+        local_description = f"{name} at {fname}:{caller.f_lineno}"
         try:
             description_stack.append(local_description)
             description = " in ".join(reversed(description_stack)) + " passed"
@@ -97,7 +89,7 @@ if IN_COVERAGE_TESTS:
         with check_block(name, 2):
             yield
 
-    def check_function(f):
+    def check_function(f: Func) -> Func:
         @proxies(f)
         def accept(*args, **kwargs):
             # depth of 2 because of the proxy function calling us.
@@ -106,10 +98,9 @@ if IN_COVERAGE_TESTS:
 
         return accept
 
-
 else:  # pragma: no cover
 
-    def check_function(f):
+    def check_function(f: Func) -> Func:
         return f
 
     @contextmanager
